#
# spec file for package streamripper
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define _lto_cflags %nil

Name:           streamripper
Version:        1.64.6
Release:        pm153.3.1
Summary:        Record shoutcast compatible streams
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Other
URL:            https://sourceforge.net/projects/streamripper
Source:         http://switch.dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
Patch0:         %{name}-implicit-fortify-decl.patch
BuildRequires:  glib2-devel
BuildRequires:  libfaad-devel
BuildRequires:  libmad-devel
BuildRequires:  libogg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
Streamripper records shoutcast compatible streams. Shoutcast style
streams contain "meta data" or track separation data, it uses that as a
marker for where the track should be separated, next the MP3 data is
decoded and scanned for a silent point which is where tracks will be
created. Finally, tracks are placed nicely on your harddrive with
appropriate names and separation.

%prep
%setup -q
%patch0 -p1

%build
touch NEWS AUTHORS ChangeLog
pushd libmad*
touch NEWS AUTHORS ChangeLog
popd
#autoreconf --force --install

export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--prefix=%{_prefix} \
	--mandir=%{_mandir} \
	--with-included-libmad=no \
	--with-included-tre=no
%make_build

%install
%make_install

%files
%doc README
%{_mandir}/man1/*
%{_bindir}/*

%changelog
* Sun Jan 15 2023 Hans-Peter Jansen <hpj@urpla.net>
- run through spec-cleaner and spec2changes.pl and fix Fallout
- build with LTO disabled (seems to provide slightly better results)
- remove nonsensical streamripper-rpmlintrc
* Wed Apr 29 2009 toni@links2linux.de
- new upstream version 1.64.6
- added ncurses-devel and libfaad-devel to BuildRequires
- Fix bug which creates corrupted id3v2 tags
- Remove trailing periods for stream name
* Sun Mar  8 2009 detlef@links2linux.de
- new upstream version <1.64.5>
  * Change default values for
- localhost from "localhost" to "127.0.0.1"
- splitpoint padding from 300 ms to 0 ms
- metadata and relay codeset (if UTF-8) to ISO-8859-1
- id3 codeset to UTF-16
- "keep files in incomplete" from false to true
  * Fix parse rules to properly tag artists with "-" in their name (#540543)
  * Fix bitrate & metadata reporting in console (#1957248)
  * Fix integer overflow on bytes read (#1261305)
  * Option for stopping based on megabytes ripped now uses MiB instead of MB
  * Support splitting based on empty StreamTitle= strings 2648664
* Fri Feb 20 2009 detlef@links2linux.de
- new upstream version <1.64.4>
  * Fix problem where corrupt ogg files are being created
  * Robustify metadata parsing for Limecast servers
  * Fix buffer overflow bug with substitution rules (#2492422)
  * Fix file creation bug when "/" is in stream name (#2533980)
  * Disable creating cue file for ogg streams
  * Fix problem skipping extra track on ogg streams
* Sun Dec 28 2008 detlef@links2linux.de
- new upstream version <1.64.3>
  * Fix bug where ogg streams with repeated metadata were being split
* Sat Dec 13 2008 detlef@links2linux.de
- Update to version 1.64.1
  * Plugin: Streamripper can now load zipped skins
  * Plugin: Streamripper skins can be (slightly) configured to use different
  image regions. This fixes the "extra pixel" bug.
  * Streamripper again skips leading dots "." when making files & directories
  * Fix problem with control characters in metadata
  * Fix crash when splitting without padding and without search window
  * Workaround problem with ogg streams which don't send any metadata
  * Streamripper now respects user timeout in more situations
  * Add --xs-none option
* Tue Dec  9 2008 detlef@links2linux.de
- Update to version 1.64.0
* Tue Sep 25 2007 henne@links2linux.de
- Update to version 1.62.3
* Mon Aug 27 2007 henne@links2linux.de
- Update to version 1.62.2
* Tue Dec 19 2006 henne@links2linux.de
- update to version 1.61.27
* Tue Mar 21 2006 henne@links2linux.de
- update to version 1.61.18
- add libogg-devel libvorbis-devel to buildrequires
* Wed Mar 15 2006 henne@links2linux.de
- update to 1.61.17
* Mon Sep 19 2005 henne@links2linux.de
- First packman release
